DeviceFontSizesPresets class
Properties
- desktop → AppFontSizes
-
final
- desktopCompact → AppFontSizes
-
final
- desktopMarketing → AppFontSizes
-
final
- desktopReading → AppFontSizes
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mobile → AppFontSizes
-
final
- mobileComfortable → AppFontSizes
-
final
- mobileCompact → AppFontSizes
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tablet → AppFontSizes
-
final
- tabletReading → AppFontSizes
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited