Consts class

Punto de acceso central para todas las constantes de diseño

Uso:

// Duraciones
Consts.durations.base.md  // 300ms
Consts.durations.feat.searchDebounce  // 300ms

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

durations AppDurationsSystem
Sistema de duraciones para animaciones y transiciones
no setter
fontSizes FontSizesSystem
Sistema de tamaños de fuente tipográficos jerárquicos
no setter
radius AppRadiusSystem
Sistema de radius para bordes redondeados y formas
no setter
sizes AppSizesSystem
Sistema de tamaños base para toda la aplicación
no setter
spacing AppSpacingSystem
Sistema de espaciado para padding, margin y gaps
no setter
ui AppUISystem
Sistema jerárquico de UI (elevaciones, opacidades, iconos, avatares, breakpoints y aspect ratios) con autocompletado por categorías.
no setter