AppSizesBreakpoints class

Breakpoints responsivos para diferentes dispositivos

Define los anchos máximos para adaptar el layout según el tamaño del dispositivo.

🎨 Uso

// Detectar tipo de dispositivo
final width = MediaQuery.of(context).size.width;

if (width < AppSizesBreakpoints._().mobile) {
  // Layout móvil
} else if (width < AppSizesBreakpoints._().tablet) {
  // Layout tablet
} else {
  // Layout desktop
}

// Limitar ancho de contenido
Container(
  constraints: BoxConstraints(
    maxWidth: AppSizesBreakpoints._().content,
  ),
)

Properties

content double
1536.0 - Ancho máximo para contenido centrado
no setter
desktop double
1200.0 - Ancho máximo para desktop
no setter
hashCode int
The hash code for this object.
no setterinherited
mobile double
600.0 - Ancho máximo para móviles
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tablet double
900.0 - Ancho máximo para tablets
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited