AppSizesIcons class

Tamaños de iconos según Material Design

Proporciona los tamaños estándar para iconos basados en las guías de Material Design.

🎨 Uso

Icon(
  Icons.home,
  size: AppSizesIcons._().lg,  // 24.0 (estándar)
)

Icon(
  Icons.badge,
  size: AppSizesIcons._().xs,  // 12.0 (pequeño)
)

Properties

hashCode int
The hash code for this object.
no setterinherited
huge double
48.0 - Iconos enormes (splash, empty states)
no setter
lg double
24.0 - Estándar Material Design
no setter
md double
20.0 - Iconos medianos (botones)
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sm double
16.0 - Iconos pequeños (inputs, chips)
no setter
xl double
32.0 - Iconos grandes (headers)
no setter
xs double
12.0 - Iconos extra pequeños (badges, indicators)
no setter
xxl double
40.0 - Iconos muy grandes (hero sections)
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited