AppSizesOpacities class

Niveles de opacidad según Material Design

Proporciona los valores estándar de opacidad para estados y transparencia de elementos.

🎨 Uso

// Texto deshabilitado
Opacity(
  opacity: AppSizesOpacities._().disabled,  // 0.38
  child: Text('Deshabilitado'),
)

// Efecto hover
Container(
  color: Colors.black.withOpacity(AppSizesOpacities._().hover),  // 0.12
)

Properties

disabled double
0.38 - Elementos deshabilitados
no setter
full double
1.0 - Completamente opaco
no setter
hashCode int
The hash code for this object.
no setterinherited
high double
0.87 - Texto principal
no setter
hover double
0.12 - Hover/ripple effects
no setter
medium double
0.54 - Texto secundario
no setter
mediumHigh double
0.70 - Elementos menos importantes
no setter
none double
0.0 - Completamente transparente
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited