AppSpacingGapHorizontal class

SizedBox para gaps horizontales (ancho)

Proporciona SizedBox pre-configurados para separar widgets horizontalmente en Row o layouts horizontales.

🎨 Uso

Row(
  children: [
    Icon(Icons.star),
    AppSpacingGapHorizontal._().sm,  // SizedBox(width: 6.0)
    Text('5.0'),
  ],
)

Properties

giant → SizedBox
48.0 - Gap horizontal gigante
no setter
hashCode → int
The hash code for this object.
no setterinherited
huge → SizedBox
32.0 - Gap horizontal enorme
no setter
lg → SizedBox
16.0 - Gap horizontal grande (común en Row)
no setter
lgx → SizedBox
18.0 - Gap horizontal grande-extra
no setter
massive → SizedBox
40.0 - Gap horizontal masivo
no setter
md → SizedBox
12.0 - Gap horizontal mediano
no setter
mdl → SizedBox
14.0 - Gap horizontal mediano-grande
no setter
mds → SizedBox
10.0 - Gap horizontal mediano-pequeño
no setter
mega → SizedBox
56.0 - Gap horizontal mega
no setter
none → SizedBox
0.0 - Sin espacio horizontal
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sm → SizedBox
6.0 - Gap horizontal pequeño
no setter
smd → SizedBox
8.0 - Gap horizontal pequeño-mediano
no setter
ultra → SizedBox
64.0 - Gap horizontal ultra
no setter
xl → SizedBox
20.0 - Gap horizontal extra grande
no setter
xs → SizedBox
4.0 - Gap horizontal extra pequeño
no setter
xxl → SizedBox
24.0 - Gap horizontal extra extra grande
no setter
xxs → SizedBox
2.0 - Gap horizontal extra extra pequeño
no setter
xxxl → SizedBox
28.0 - Gap horizontal extra extra extra grande
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited