AppUIBreakpoints class

Properties

content double
1536.0 - Ancho máximo para contenido centrado
no setter
desktop double
1200.0 - Ancho máximo para desktop
no setter
hashCode int
The hash code for this object.
no setterinherited
mobile double
600.0 - Ancho máximo para dispositivos móviles
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tablet double
900.0 - Ancho máximo para tablets
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited