BaseFontSizesPresets class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hFLS → AppFontSizes
-
final
- hFNS → AppFontSizes
-
final
- hFSS → AppFontSizes
-
final
- hFXLS → AppFontSizes
-
final
- lFLS → AppFontSizes
-
final
- lFNS → AppFontSizes
-
final
- lFSS → AppFontSizes
-
final
- lFXLS → AppFontSizes
-
final
- nFLS → AppFontSizes
-
final
- nFNS → AppFontSizes
-
final
- nFSS → AppFontSizes
-
final
- nFXLS → AppFontSizes
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sFLS → AppFontSizes
-
final
- sFNS → AppFontSizes
-
final
- sFSS → AppFontSizes
-
final
- sFXLS → AppFontSizes
-
final
- xLFLS → AppFontSizes
-
final
- xLFNS → AppFontSizes
-
final
- xLFSS → AppFontSizes
-
final
- xLFXLS → AppFontSizes
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited