ComponentsFontSizesPresets class
Properties
- badge → AppFontSizes
-
final
-
final
-
final
-
final
-
final
-
final
- captionDesktop → AppFontSizes
-
final
- captionEmphasis → AppFontSizes
-
final
- captionMobile → AppFontSizes
-
final
- captionTablet → AppFontSizes
-
final
- dialogTitle → AppFontSizes
-
final
- formHint → AppFontSizes
-
final
- formLabelDesktop → AppFontSizes
-
final
- formLabelMobile → AppFontSizes
-
final
- formLabelTablet → AppFontSizes
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- listItemSubtitle → AppFontSizes
-
final
- listItemTitle → AppFontSizes
-
final
-
final
- notification → AppFontSizes
-
final
- overlineLarge → AppFontSizes
-
final
- overlineStandard → AppFontSizes
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tabLabel → AppFontSizes
-
final
- tooltip → AppFontSizes
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited