AppSizesAspectRatios class
Proporciones de aspecto comunes (Aspect Ratios)
Proporciona las relaciones de aspecto estándar para imágenes, videos y contenedores.
🎨 Uso
AspectRatio(
aspectRatio: AppSizesAspectRatios._().wide, // 16:9
child: Image.network('url'),
)
AspectRatio(
aspectRatio: AppSizesAspectRatios._().square, // 1:1
child: Container(...),
)
Properties
- cinematic → double
-
2.35 - Cinemático (21:9)
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- photo → double
-
1.5 - Foto (3:2)
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- square → double
-
1.0 - Cuadrado (1:1)
no setter
- standard → double
-
1.33 - Estándar (4:3)
no setter
- wide → double
-
1.78 - Widescreen (16:9)
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited