AppSizesElevations class
Niveles de elevación según Material Design
Proporciona los valores estándar de elevación para sombras y profundidad visual.
🎨 Uso
Card(
elevation: AppSizesElevations._().md, // 4.0
child: ...,
)
Material(
elevation: AppSizesElevations._().massive, // 24.0
child: ...,
)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- huge → double
-
16.0 - Elevación enorme (navigation drawer)
no setter
- lg → double
-
6.0 - Elevación media (FAB)
no setter
- massive → double
-
24.0 - Elevación masiva (modal sheets)
no setter
- md → double
-
4.0 - Elevación estándar (cards, app bar)
no setter
- none → double
-
0.0 - Sin elevación
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sm → double
-
2.0 - Elevación baja (botones, chips)
no setter
- xl → double
-
8.0 - Elevación alta (drawer, bottom sheet)
no setter
- xs → double
-
1.0 - Elevación mínima (cards en reposo)
no setter
- xxl → double
-
12.0 - Elevación muy alta (dialogs)
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited