AppSpacingHorizontal class
EdgeInsets con padding horizontal (EdgeInsets.symmetric)
Proporciona EdgeInsets pre-configurados con padding solo en los lados.
🎨 Uso
Container(
padding: AppSpacingHorizontal._().lg, // EdgeInsets.symmetric(horizontal: 16.0)
child: Row(
children: [...],
),
)
Properties
- giant → EdgeInsets
-
48.0 - Padding horizontal gigante
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- huge → EdgeInsets
-
32.0 - Padding horizontal enorme
no setter
- lg → EdgeInsets
-
16.0 - Padding horizontal grande (muy usado en screens)
no setter
- lgx → EdgeInsets
-
18.0 - Padding horizontal grande-extra
no setter
- massive → EdgeInsets
-
40.0 - Padding horizontal masivo
no setter
- md → EdgeInsets
-
12.0 - Padding horizontal mediano
no setter
- mdl → EdgeInsets
-
14.0 - Padding horizontal mediano-grande
no setter
- mds → EdgeInsets
-
10.0 - Padding horizontal mediano-pequeño
no setter
- mega → EdgeInsets
-
56.0 - Padding horizontal mega
no setter
- none → EdgeInsets
-
0.0 - Sin padding horizontal
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sm → EdgeInsets
-
6.0 - Padding horizontal pequeño
no setter
- smd → EdgeInsets
-
8.0 - Padding horizontal pequeño-mediano
no setter
- ultra → EdgeInsets
-
64.0 - Padding horizontal ultra
no setter
- xl → EdgeInsets
-
20.0 - Padding horizontal extra grande
no setter
- xs → EdgeInsets
-
4.0 - Padding horizontal extra pequeño
no setter
- xxl → EdgeInsets
-
24.0 - Padding horizontal extra extra grande
no setter
- xxs → EdgeInsets
-
2.0 - Padding horizontal extra extra pequeño
no setter
- xxxl → EdgeInsets
-
28.0 - Padding horizontal extra extra extra grande
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited