AppUISystem class
Sistema jerárquico de acceso a todas las constantes de UI
Similar a AppSizesSystem, pero usando los valores ya delegados en AppUI. Útil cuando prefieres acceso por categorías con autocompletado.
Constructors
Properties
- aspectRatios → AppUIAspectRatios
-
Proporciones de aspecto
no setter
- avatars → AppUIAvatars
-
Tamaños de avatares
no setter
- breakpoints → AppUIBreakpoints
-
Breakpoints responsivos
no setter
- elevations → AppUIElevations
-
Niveles de elevación
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- icons → AppUIIcons
-
Tamaños de iconos
no setter
- opacities → AppUIOpacities
-
Niveles de opacidad
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited